@@ -1,10 +1,16 @@
 package Data::DPath::Point;
 
-use 5.010;
 use strict;
 use warnings;
 
-use Object::Tiny::RW 'parent', 'ref', 'attrs';
+use Class::XSAccessor::Array
+    chained     => 1,
+    constructor => 'new',
+    accessors   => {
+                    parent => 0,
+                    attrs  => 1,
+                    ref    => 2,
+                   };
 
 1;
 
@@ -22,6 +28,10 @@ the result.
 
 =head1 INTERNAL METHODS
 
+=head2 new
+
+Constructor.
+
 =head2 parent
 
 Attribute / accessor.
